Author: djg
Date: Thu Oct 11 18:06:37 2007
New Revision: 42879
URL: http://llvm.org/viewvc/llvm-project?rev=42879&view=rev
Log:
Add an ISD::FPOW node type.
Modified:
llvm/trunk/include/llvm/CodeGen/SelectionDAGNodes.h
llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
Modified: llvm/trunk/include/llvm/CodeGen/SelectionDAGNodes.h
URL:
http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/CodeGen/SelectionDAGNodes.h?rev=42879&r1=42878&r2=42879&view=diff
==============================================================================
--- llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAG.cpp (original)
+++ llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAG.cpp Thu Oct 11 18:06:37
2007
@@ -3602,6 +3602,7 @@
case ISD::FSIN: return "fsin";
case ISD::FCOS: return "fcos";
case ISD::FPOWI: return "fpowi";
+ case ISD::FPOW: return "fpow";
// Binary operators
case ISD::ADD: return "add";
_______________________________________________
llvm-commits mailing list
[email protected]
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits
--- llvm/trunk/include/llvm/CodeGen/SelectionDAGNodes.h (original)
+++ llvm/trunk/include/llvm/CodeGen/SelectionDAGNodes.h Thu Oct 11 18:06:37 2007
@@ -408,10 +408,10 @@
// conversions, but that is a noop, deleted by getNode().
BIT_CONVERT,
// FNEG, FABS, FSQRT, FSIN, FCOS, FPOWI - Perform unary floating point
// negation, absolute value, square root, sine and cosine, and powi
point
+ // negation, absolute value, square root, sine and cosine, powi, and pow
// operations.
- FNEG, FABS, FSQRT, FSIN, FCOS, FPOWI,
+ FNEG, FABS, FSQRT, FSIN, FCOS, FPOWI, FPOW,
// LOAD and STORE have token chains as their first operand, then the same
// operands as an LLVM load/store instruction, then an offset node that
Modified: llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
@@ -408,10 +408,10 @@
// conversions, but that is a noop, deleted by getNode().
BIT_CONVERT,
- // FNEG, FABS, FSQRT, FSIN, FCOS, FPOWI - Perform unary floating point
- // negation, absolute value, square root, sine and cosine, and powi
+ // FNEG, FABS, FSQRT, FSIN, FCOS, FPOWI, FPOW - Perform unary floating
point
URL:
http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAG.cpp?rev=42879&r1=42878&r2=42879&view=diff
==============================================================================